pub async fn serve_control_api(port: u16, state: ControlApiState) -> Result<()>Expand description
Handle the control server task. Runs until the listener errors or the task is aborted by the scenario finishing.
pub async fn serve_control_api(port: u16, state: ControlApiState) -> Result<()>Handle the control server task. Runs until the listener errors or the task is aborted by the scenario finishing.