run_cli

Function run_cli 

pub async fn run_cli() -> Result<()>
Run the CLI — parses args, initializes tracing, dispatches to engine.

This is the single entry point that both the standard tropel binary and custom tropel build binaries call from their fn main().